@@ -1,8 +1,9 @@
-// This are game-spcific info string for QT build of Adv550.
+// This are game-spcific info string for QT build of Adv580.
 //
-#define GAME "Adv550"
+#define GAME "Adv580"
 #define GAMEINFO "<b>" GAME "</b> " \
-"is Dave Platt's 1979 expansion of the text ur-game Adventure " \
+"is Mike Goetz's 1978 expansion of Dave Platt's Adv550, which was " \
+"in turn based on the text ur-game Adventure " \
 "(a.k.a. Collossal Cave) created by Will Crowther and Don Woods." \
 "<br> <br>" \
 "For more information on the complex family tree of Adventure " \
